@@ -108,10 +108,21 @@ class AutoSetup(ModuleInput):
         module_input_name: str = "",
     ) -> Module:
         module_kwargs = dict(self.module_kwargs)
-        if "replication_key" not in module_kwargs:
-            module_kwargs["replication_key"] = self.get_replication_key(
-                parent, module_input_name
+        try:
+            replication_key = module_kwargs["replication_key"]
+        except KeyError:
+            module_kwargs[
+                "replication_key"
+            ] = replication_key = self.get_replication_key(parent, module_input_name)
+        finally:
+            module_instnce_name = (
+                f"{self.module_class.get_class_name()}.{replication_key}"
             )
+            try:
+                return module_container.get_module_by_name(module_instnce_name)
+            except (KeyError, InvalidModuleInstanceNameError):
+                pass
+
         module = self.module_class(**module_kwargs)
         module_instance_dict = {id(module): module}
         module_name = module.get_class_name()
@@ -122,6 +133,15 @@ class AutoSetup(ModuleInput):
         return module
 
 
+class IgnoredInitializationArgumentsWarning(RuntimeWarning):
+    def __init__(self, module: Module, ignored_kwargs: dict):
+        super().__init__(
+            "The following unexpected key word arguments "
+            f"which were given to '{str(module)}' have "
+            f"been ignored by WALKMAN: {ignored_kwargs}"
+        )
+
+
 class Module(
     walkman.PlayMixin,
     walkman.JumpToMixin,
@@ -210,8 +230,9 @@ class Module(
     def _stop(self, wait: float = 0):
         self._stop_without_fader(wait=wait)
 
-    def _initialise(self, **_):
-        ...
+    def _initialise(self, **kwargs):
+        if kwargs:
+            warnings.warn(IgnoredInitializationArgumentsWarning(self, kwargs))
 
     def _setup_pyo_object(self):
         ...
@@ -524,6 +545,7 @@ class ModuleContainer(
         )
         for module in self.module_tuple:
             self.prepare_module(module)
+            module._stop_without_fader()
 
         for module in self.module_tuple:
             if not (is_send_to_physical_output := module.send_to_physical_output):
